tiled.adapters.array.ArrayAdapter
=================================

.. currentmodule:: tiled.adapters.array

.. autoclass:: ArrayAdapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ArrayAdapter.__init__
      ~ArrayAdapter.from_array
      ~ArrayAdapter.macrostructure
      ~ArrayAdapter.microstructure
      ~ArrayAdapter.read
      ~ArrayAdapter.read_block
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ArrayAdapter.metadata
      ~ArrayAdapter.structure_family
   
   